LinkType

Enum LinkType 

pub enum LinkType {
    Null(Linktype),
    Ethernet(Linktype),
    RawIp(Linktype),
    Loop(Linktype),
    IPv4(Linktype),
    IPv6(Linktype),
    LinuxSll(Linktype),
    LinuxSll2(Linktype),
    Unsupported(Linktype),
}
Link types this crate can parse.

LinkType::Unsupported is still parsed, as Ethernet, on the assumption that an unknown DLT is more often Ethernet-shaped than not.

Variants



Null(Linktype)



Ethernet(Linktype)



RawIp(Linktype)



Loop(Linktype)



IPv4(Linktype)



IPv6(Linktype)



LinuxSll(Linktype)



LinuxSll2(Linktype)



Unsupported(Linktype)

Implementations

Source

impl LinkType

pub fn from_pcap(link_type: Linktype) -> Self

Convert a pcap::Linktype to a LinkType.

pub fn is_supported(self) -> bool

Whether the link type is supported by this crate.

pub fn description(self) -> String

Returns a human-readable description of the link type.