pub struct ParsedPacket {
pub link_info: LinkInfo,
pub net_info: NetInfo,
pub transport_info: TransportInfo,
}Expand description
Parsed network packet with info extracted from its headers.
Fields
link_info: LinkInfoInfo extracted from the data link layer header.
net_info: NetInfoInfo extracted from the network layer header.
transport_info: TransportInfoInfo extracted from the transport layer header.
Implementations
Sourceimpl ParsedPacket
impl ParsedPacket
Sourcepub fn from_bytes(bytes: &[u8], link_type: LinkType) -> Option<ParsedPacket>
pub fn from_bytes(bytes: &[u8], link_type: LinkType) -> Option<ParsedPacket>
Parse one raw network packet from its link type and wire bytes.
Sourcepub fn bytes_count(&self) -> usize
pub fn bytes_count(&self) -> usize
Returns the total number of bytes in the packet.