pub struct TransportInfo {
pub src_port: Option<u16>,
pub dst_port: Option<u16>,
pub protocol: Protocol,
pub icmp_type: Option<IcmpType>,
pub igmp_type: Option<IgmpType>,
}Expand description
Info extracted from the transport layer header.
Fields
src_port: Option<u16>Source port, if the packet is a TCP or UDP packet.
dst_port: Option<u16>Destination port, if the packet is a TCP or UDP packet.
protocol: ProtocolProtocol carried by the packet.
icmp_type: Option<IcmpType>ICMP message type, if the packet is an ICMP packet.
igmp_type: Option<IgmpType>IGMP message type, if the packet is an IGMP packet.